@@ -27,7 +27,7 @@
  * list of people on the gedit Team.
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-commands-file.c 5993 2007-11-02 14:30:31Z sfre $
+ * $Id: gedit-commands-file.c 6026 2007-12-15 11:50:12Z pborelli $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -164,7 +164,8 @@ load_file_list (GeditWindow         *window,
 						doc = gedit_tab_get_document (tab);
 						view = gedit_tab_get_view (tab);
 
-						gedit_document_goto_line (doc, line_pos);
+						/* document counts lines starting from 0 */
+						gedit_document_goto_line (doc, line_pos - 1);
 						gedit_view_scroll_to_cursor (view);
 					}
 				}
@@ -316,7 +317,7 @@ gedit_commands_load_uri (GeditWindow         *window,
 }
 
 /**
- * gedit_commands_load_uri:
+ * gedit_commands_load_uris:
  *
  * Ignore non-existing URIs 
  */
@@ -350,7 +351,6 @@ _gedit_cmd_load_files_from_prompt (GeditWindow         *window,
 	return load_file_list (window, uris, encoding, line_pos, TRUE);
 }
 
-
 static void
 open_dialog_destroyed (GeditWindow            *window,
 		       GeditFileChooserDialog *dialog)
