@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-documents-panel.c 5356 2006-12-10 17:02:05Z paolo $
+ * $Id: gedit-documents-panel.c 6112 2008-01-23 08:26:24Z sfre $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -300,15 +300,22 @@ window_tab_added (GeditWindow         *window,
 	}
 	else
 	{
-		GtkTreeSelection *selection;
+		GeditTab *active_tab;
 
 		gtk_list_store_append (GTK_LIST_STORE (panel->priv->model), 
 				       &iter);
 
-		selection = gtk_tree_view_get_selection (
-					GTK_TREE_VIEW (panel->priv->treeview));
+		active_tab = gedit_window_get_active_tab (panel->priv->window);
 
-		gtk_tree_selection_select_iter (selection, &iter);
+		if (tab == active_tab)
+		{
+			GtkTreeSelection *selection;
+
+			selection = gtk_tree_view_get_selection (
+						GTK_TREE_VIEW (panel->priv->treeview));
+
+			gtk_tree_selection_select_iter (selection, &iter);
+		}
 	}
 
 	name = tab_get_name (tab);
@@ -458,7 +465,8 @@ gedit_documents_panel_class_init (GeditDocumentsPanelClass *klass)
 							 "The GeditWindow this GeditDocumentsPanel is associated with",
 							 GEDIT_TYPE_WINDOW,
 							 G_PARAM_READWRITE |
-							 G_PARAM_CONSTRUCT_ONLY));	
+							 G_PARAM_CONSTRUCT_ONLY |
+							 G_PARAM_STATIC_STRINGS));
 
 	g_type_class_add_private (object_class, sizeof(GeditDocumentsPanelPrivate));
 }
@@ -610,6 +618,63 @@ panel_popup_menu (GtkWidget           *treeview,
 	return FALSE;
 }
 
+static gboolean
+treeview_query_tooltip (GtkWidget  *widget,
+			gint        x,
+			gint        y,
+			gboolean    keyboard_tip,
+			GtkTooltip *tooltip,
+			gpointer    data)
+{
+	GtkTreeIter iter;
+	GtkTreeView *tree_view = GTK_TREE_VIEW (widget);
+	GtkTreeModel *model = gtk_tree_view_get_model (tree_view);
+	GtkTreePath *path = NULL;
+	gpointer *tab;
+	gchar *tip;
+
+	if (keyboard_tip)
+	{
+		gtk_tree_view_get_cursor (tree_view, &path, NULL);
+
+		if (path == NULL)
+		{
+			return FALSE;
+		}
+	}
+	else
+	{
+		gint bin_x, bin_y;
+
+		gtk_tree_view_convert_widget_to_bin_window_coords (tree_view,
+								   x, y,
+								   &bin_x, &bin_y);
+      
+		if (!gtk_tree_view_get_path_at_pos (tree_view,
+						    bin_x, bin_y,
+						    &path,
+						    NULL, NULL, NULL))
+		{
+			return FALSE;
+		}
+	}
+
+	gtk_tree_model_get_iter (model, &iter, path);
+	gtk_tree_model_get (model, 
+			    &iter, 
+			    2, 
+			    &tab, 
+			    -1);
+
+	tip = _gedit_tab_get_tooltips (GEDIT_TAB (tab));
+	gtk_tooltip_set_markup (tooltip, tip);
+
+	g_free (tip);
+	gtk_tree_path_free (path);
+
+	return TRUE;
+}
+
 static void
 treeview_row_inserted (GtkTreeModel        *tree_model,
 		       GtkTreePath         *path,
@@ -686,7 +751,9 @@ gedit_documents_panel_init (GeditDocumentsPanel *panel)
   	gtk_container_add (GTK_CONTAINER (sw), panel->priv->treeview);
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (panel->priv->treeview), FALSE);
 	gtk_tree_view_set_reorderable (GTK_TREE_VIEW (panel->priv->treeview), TRUE);
-	
+
+	g_object_set (panel->priv->treeview, "has-tooltip", TRUE, NULL);
+
 	gtk_widget_show (panel->priv->treeview);
 	
 	column = gtk_tree_view_column_new ();
@@ -719,6 +786,10 @@ gedit_documents_panel_init (GeditDocumentsPanel *panel)
 			  "popup-menu",
 			  G_CALLBACK (panel_popup_menu),
 			  panel);
+  	g_signal_connect (panel->priv->treeview,
+			  "query-tooltip",
+			  G_CALLBACK (treeview_query_tooltip),
+			  NULL);
 
 	g_signal_connect (panel->priv->model, 
 			  "row-inserted",
